#ifndef TAPEPOSITIONINGSYSTEM_HEADERS
#define TAPEPOSITIONINGSYSTEM_HEADERS

// All headers of TapePositioningSystem library

#include "Anchorage.h"
#include "ClusterQuads.h"
#include "Node.h"
#include "TapePositioningSystemDLLExport.h"
#include "Triangulator.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace TapePositioningSystem;
#endif

#endif // TAPEPOSITIONINGSYSTEM_HEADERS
